==> qtjambi-sql-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiSql/QSqlDriverPlugin_shell.h <==
#ifndef QSQLDRIVERPLUGIN_SHELL_H
#define QSQLDRIVERPLUGIN_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtSql/qsqldriverplugin.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtSql/qsqldriver.h>
#include <QtJambi/RegistryAPI>


class QSqlDriverPlugin_shell : public QSqlDriverPlugin, public QtJambiShellInterface
{
public:
    QSqlDriverPlugin_shell(QObject* parent0 = nullptr);
    ~QSqlDriverPlugin_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QSqlDriver* create(const QString& key0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSqlDriverPlugin_access : public QSqlDriverPlugin
{
    jobject __qt_create_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring key0);
};

#endif // QSQLDRIVERPLUGIN_SHELL_H

==> qtjambi-sql-debuginfo-linux-x64-6.5.9.jar: sources/QtJambiSql/QSqlDriverPlugin_shell.h <==
#ifndef QSQLDRIVERPLUGIN_SHELL_H
#define QSQLDRIVERPLUGIN_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtSql/qsqldriverplugin.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtSql/qsqldriver.h>
#include <QtJambi/RegistryAPI>


class QSqlDriverPlugin_shell : public QSqlDriverPlugin, public QtJambiShellInterface
{
public:
    QSqlDriverPlugin_shell(QObject* parent0 = nullptr);
    ~QSqlDriverPlugin_shell() override;
private:
    QtJambiShell* __shell() const override final;
    friend class QSqlDriverPlugin_mshell;
    friend class QSqlDriverPlugin_oshell;
};


class QSqlDriverPlugin_mshell : public QSqlDriverPlugin_shell
{
public:
    using QSqlDriverPlugin_shell::QSqlDriverPlugin_shell;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QSqlDriverPlugin_oshell : public QSqlDriverPlugin_mshell
{
public:
    using QSqlDriverPlugin_mshell::QSqlDriverPlugin_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QSqlDriver* create(const QString& key0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSqlDriverPlugin_access : public QSqlDriverPlugin
{
    jobject __qt_create_cref_QString(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring key0);
};

#endif // QSQLDRIVERPLUGIN_SHELL_H
